<div class="post rich">
    {% if not 'img' in object.content %}
        <img src="{{ object.get_event_medium_url }}" width="269" height="151" alt="" />
    {% endif %}
    <p>{{ object.content|safe }}</p>
</div><!--/post-->
