{% load panya_template_tags %}

<div class="intro">
	<a href="{% url event_object_detail object.slug %}" class="intro_pic"><img src="{{ object.get_event_entryitem_wide_url }}" width="107" height="60" alt="" /><span></span></a>
	<p class="meta">Location: {{ object.venue.name }}, {{ object.venue.location.city }}</p>
	<h3><a href="{% url event_object_detail object.slug %}">{{ object.title }}</a></h3>
	<p class="blurb">{{ object.description|truncatewords:12 }} <a href="{% url event_object_detail object.slug %}">More</a></p>
	<a href="{% url event_object_detail object.slug %}#comments" class="intro_comments">{{ object.comment_count }} Comments</a>
	<span class="intro_likes">{{ object.vote_total }} Likes</span>
</div>
