{% load panya_inclusion_tags humanize %}

{% regroup object_list by start.date as group_list %}

{% for item in group_list %}
    <div class="stamp">
        <p><span class="stamp_month">{{ item.grouper|date:"M"}}</span><span class="stamp_day">{{ item.grouper|date:"d"}}</span></p>
        <h3>{{ item.grouper|naturalday:"l d F Y"|title }}</h3>
    </div>
    {% for object in item.list %}
        {% with object as entryitem %}
            {% render_object object.content.as_leaf_class "entryitem_list_wide" %}
        {% endwith %}
    {% endfor %}
{% endfor %}
