{% extends "base.html" %}
{% load panya_inclusion_tags event_inclusion_tags %} 

{% block content %}
    <div class="page section_events">
	    <div class="title">
		    <h1>{{ title }}</h1>
		</div>
		
		{% view_modifier view_modifier %}

        {% event_entryitem_listing object_list %}

        {% pager page_obj %}

	</div>
{% endblock %}
